##  Importing Jira Work Items as Child Initiative Fact Sheets
Add your Jira work items to SAP LeanIX as initiatives. When you import a Jira work item as a fact sheet for an initiative, SAP LeanIX adds it as child initiative and sets up syncing for mapped fields.
To create a child fact sheet for an initiative, do the following:
  1. Open an initiative fact sheet and go to the Agile Tracking tab.
  2. To set up synchronization, choose Set up Sync and select Import from Atlassian Jira.
  3. Choose the Jira project that contains the relevant work items.
  4. Apply filters or use the search field to narrow down relevant Jira work items. Learn more about what you can filter by in [Searching and Filtering for Jira Work Items](https://help.sap.com/docs/leanix/ea/creating-and-linking-fact-sheets-and-jira-issues?locale=en-US&state=PRODUCTION&version=CLOUD#loio1326ff7bd12b41a7a5a92531f2c63445__section_okw_cqv_lgc).
Select the work items that you want to import.
  5. Preview the selected issues and their mappings.
  6. Choose Create and Sync to complete the import.


Imported Jira work items appear as child fact sheets under the selected initiative. They include all mapped fields and direct links to the original Jira tickets. The system automatically synchronizes data every 30 minutes.
Choose Import More to import additional work items.
List of Imported Work Items
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio3dca3bec32fb4469b892875f73b7257a_LowRes.png)
